It fits MASEM with the one-stage MASEM (OSMASEM) approach.
osmasem(model.name="osmasem", Mmatrix, Tmatrix, data, subset=NULL,
intervals.type=c("z", "LB"), mxModel.Args=NULL,
mxRun.Args=NULL, suppressWarnings=TRUE,
silent=TRUE, run=TRUE, ...)A string for the model name in mxModel.
A list of matrices of the model implied correlation
matrix created by the create.vechsR.
A list of matrices of the heterogeneity
variance-covariance matrix created by the create.Tau2.
A list of data created by the Cor2DataFrame.
A character vector of the observed variables selected for the analysis.
Either z (default if missing) or
LB. If it is z, it calculates the 95% confidence
intervals (CIs) based on the estimated standard error. If it
is LB, it calculates the 95% likelihood-based CIs on the parameter estimates.
A list of arguments passed to mxModel.
A list of arguments passed to mxRun.
Logical. If it is TRUE, warnings are
suppressed. This argument is passed to mxRun.
Logical. An argument is passed to mxRun
Logical. If FALSE, only return the mx model without running the analysis.
Not used yet.
An object of class osmasem
Jak, S., & Cheung, M. W.-L. (2019). Meta-analytic structural equation modeling with moderating effects on SEM parameters. Psychological Methods.