Learn R Programming

metaSEM (version 0.9.8)

HedgesOlkin85: Effects of Open Education Reported by Hedges and Olkin (1985)

Description

Effects of open education on attitude toward school and on reading achievement reported by Hedges and Olkin (1985).

Usage

data(HedgesOlkin85)

Arguments

Hedges, L. V., & Olkin, I. (1985). Statistical methods for meta-analysis. Orlando, FL: Academic Press.

Details

The variables are:
study
Study number

d_att
Standardized mean difference on attitude

d_ach
Standardized mean difference on achievement

var_att
Sampling variance of the effect size of attitude

cov_att_ach
Sampling covariance between the effect sizes

var_ach
Sampling variance of the effect size of achievement

References

Cheung, M. W.-L. (2010). Fixed-effects meta-analyses as multiple-group structural equation models. Structural Equation Modeling, 17, 481-509.

Examples

Run this code
data(HedgesOlkin85)

## Fixed-effects meta-analysis
summary( meta(y=cbind(d_att, d_ach),
              v=cbind(var_att, cov_att_ach, var_ach),
              data=HedgesOlkin85,
              RE.constraints=matrix(0, nrow=2, ncol=2)) )

Run the code above in your browser using DataLab