## Not run:
# data(issp89)
#
# #### Analysis of correlation structure in Cheung and Chan (2005)
# #### Fixed-effects model: Stage 1 analysis
# cor1 <- tssem1(issp89$data, issp89$n, method="FEM", cor.analysis=TRUE)
# summary(cor1)
#
# ## Prepare a model implied matrix
# ## Factor correlation matrix
# Phi <- create.mxMatrix( c("0.3*corf2f1","0.3*corf3f1","0.3*corf3f2"),
# type="Stand", as.mxMatrix=FALSE )
# ## Error variances
# Psi <- create.mxMatrix( paste("0.2*e", 1:9, sep=""), type="Diag",
# as.mxMatrix=FALSE )
#
# ## Create Smatrix
# S1 <- bdiagMat(list(Psi, Phi))
# ## dimnames(S1)[[1]] <- dimnames(S1)[[2]] <- c(paste("x",1:9,sep=""),
# ## paste("f",1:3,sep=""))
# ## S1
# S1 <- as.mxMatrix(S1)
#
# ## Factor loadings
# Lambda <- create.mxMatrix( c(".3*f1x1",".3*f1x2",".3*f1x3",rep(0,9),
# ".3*f2x4",".3*f2x5",".3*f2x6",".3*f2x7",
# rep(0,9),".3*f3x8",".3*f3x9"), type="Full",
# ncol=3, nrow=9, as.mxMatrix=FALSE )
# Zero1 <- matrix(0, nrow=9, ncol=9)
# Zero2 <- matrix(0, nrow=3, ncol=12)
#
# ## Create Amatrix
# A1 <- rbind( cbind(Zero1, Lambda),
# Zero2 )
# ## dimnames(A1)[[1]] <- dimnames(A1)[[2]] <- c(paste("x",1:9,sep=""),
# ## paste("f",1:3,sep=""))
# ## A1
# A1 <- as.mxMatrix(A1)
#
# ## Create Fmatrix
# F1 <- create.Fmatrix(c(rep(1,9), rep(0,3)))
#
# #### Fixed-effects model: Stage 2 analysis
# cor2 <- tssem2(cor1, Amatrix=A1, Smatrix=S1, Fmatrix=F1, intervals.type="LB")
# summary(cor2)
#
# #### Analysis of covariance structure in Cheung and Chan (2009)
# #### Fixed-effects model: Stage 1 analysis
# cov1 <- tssem1(issp89$data, issp89$n, method="FEM", cor.analysis=FALSE)
# summary(cov1)
#
# #### Fixed-effects model: Stage 2 analysis
# cov2 <- tssem2(cov1, Amatrix=A1, Smatrix=S1, Fmatrix=F1)
# summary(cov2)
# ## End(Not run)
Run the code above in your browser using DataLab